pilas.imagenes

Package pilas :: Module imagenes |
[hide private]
[frames] | no frames]

# Module imagenes

source code

Functions | [hide private]
cargar(ruta) Intenta cargar la imagen indicada por el argumento ``ruta``. | source code
cargar_grilla(ruta, columnas=1, filas=1) Representa una grilla de imagenes con varios cuadros de animación. | source code
cargar_lienzo() Representa un rectangulo (inicialmente transparente) para dibujar. | source code
cargar_superficie(ancho, alto) | source code
cargar_imagen(ruta) Intenta cargar la imagen indicada por el argumento ``ruta``. | source code

Variables | [hide private]
| __package__ = ``'``pilas``'``

Function Details | [hide private]

### cargar(ruta) | source code
    Intenta cargar la imagen indicada por el argumento ``ruta``.

    Por ejemplo::

        import pilas

        imagen = pilas.imagenes.cargar("mi_archivo.png")

    En caso de éxito retorna el objeto Image, que se puede asignar
    a un Actor.

    El directorio de búsqueda de la imagen sigue el siguiente orden:

        * primero busca en el directorio actual.
        * luego en 'data'.
        * por último en el directorio estándar de la biblioteca.

    En caso de error genera una excepción de tipo IOError.

### cargar_grilla(ruta, columnas=1, filas=1) | source code
Representa una grilla de imagenes con varios cuadros de animación. Una grilla es un objeto que se tiene que inicializar con la ruta a una imagen, la cantidad de columnas y filas. Por ejemplo, si tenemos una grilla con 2 columnas y 3 filas podemos asociarla a un actor de la siguiente manera:
       grilla = pilas.imagenes.cargar_grilla("animacion.png", 2, 3)
       grilla.asignar(actor)
Entonces, a partir de ahora nuestro actor muestra solamente un cuadro de toda la grilla. Si quieres avanzar la animacion tienes que modificar el objeto grilla y asignarlo nuevamente al actor:
       grilla.avanzar()
       grilla.asignar(actor)

### cargar_imagen(ruta) | source code
    Intenta cargar la imagen indicada por el argumento ``ruta``.

    Por ejemplo::

        import pilas

        imagen = pilas.imagenes.cargar("mi_archivo.png")

    En caso de éxito retorna el objeto Image, que se puede asignar
    a un Actor.

    El directorio de búsqueda de la imagen sigue el siguiente orden:

        * primero busca en el directorio actual.
        * luego en 'data'.
        * por último en el directorio estándar de la biblioteca.

    En caso de error genera una excepción de tipo IOError.